@@ -1,11 +1,11 @@
 package TeX::AutoTeX;
 
 #
-# $Id: AutoTeX.pm,v 1.20.2.7 2011/01/27 18:56:29 thorstens Exp $
-# $Revision: 1.20.2.7 $
+# $Id: AutoTeX.pm,v 1.20.2.4 2011/01/22 04:50:56 thorstens Exp $
+# $Revision: 1.20.2.4 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX.pm,v $
 #
-# $Date: 2011/01/27 18:56:29 $
+# $Date: 2011/01/22 04:50:56 $
 # $Author: thorstens $
 #
 
@@ -13,8 +13,8 @@ use strict;
 ### use warnings;
 use Carp;
 
-# our ($VERSION) = '$Revision: 1.20.2.7 $' =~ m{ \$Revision: \s+ (\S+) }x;
-our $VERSION = 'v0.906.0';
+# our ($VERSION) = '$Revision: 1.20.2.4 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our $VERSION = '0.9';
 
 use TeX::AutoTeX::Config qw(
 			     $AUTOTEX_ENV_PATH
@@ -198,7 +198,7 @@ logfile pre- hashref workdir chroot tex texmf texmf.cnf stampref fontmap config.
 
 TeX::AutoTeX - automated processing of (La-)TeX sources
 
-=head1 WARNING
+head1 WARNING
 
 TeX::AutoTeX::process will modify, overwrite, and delete files in the
 specified directory. It is assumed that directory is a temporary working
@@ -246,11 +246,6 @@ for many years. The resulting file(s) remain in the same directory. It is up
 to the calling process to pre- or post-process the directory contents as
 required.
 
-No particular naming conventions or other requirements are imposed on the
-source material, and sub-directories are permitted. The module attempts to
-determine processing order and input format based on file characteristics and
-heuristics and generally does not require any user input.
-
 Note that arXiv does not allow execution of external programs from C<TeX> or
 C<dvips> (paranoid setting in texmf.cnf), and that neither C<makeindex> or
 C<bibtex> or similar intermediate programs are run. These are deliberate
@@ -258,9 +253,8 @@ choices. Consequently this module doesn't provide that functionality either.
 
 =head1 METHODS
 
-The main purpose of C<TeX::AutoTeX> is to create an instance for a given
-source directory, set attributes relevant for processing and then call
-C<process> to do the work.
+The main purpose of C<TeX::AutoTeX> is to instantiate an object, set
+attributes relevant for processing and then call C<process> to do the work.
 
 =head2 new
 
@@ -450,7 +444,7 @@ Let us know L<http://arxiv.org/help/contact>
  and that the input of others will benefit arXiv.org.
 
  Code developed and contributed to by Tanmoy Bhattacharya, Rob
- Hartill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
+ Harthill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
  Refactored to separate generic code from arXiv.org specific code
  by Stephen Marsh, Michael Fromerth, and Simeon Warner 2005/2006.
 
