@@ -1,18 +1,18 @@
 package TeX::AutoTeX::Config;
 
 #
-# $Id: Config.pm,v 1.7.2.10 2011/02/02 06:26:25 thorstens Exp $
-# $Revision: 1.7.2.10 $
+# $Id: Config.pm,v 1.7.2.7 2011/01/22 04:54:15 thorstens Exp $
+# $Revision: 1.7.2.7 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/Config.pm,v $
 #
-# $Date: 2011/02/02 06:26:25 $
+# $Date: 2011/01/22 04:54:15 $
 # $Author: thorstens $
 #
 
 use strict;
 ### use warnings;
 
-our ($VERSION) = '$Revision: 1.7.2.10 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.7.2.7 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 use parent qw(Exporter);
 our @EXPORT_OK;
@@ -30,6 +30,8 @@ BEGIN {
                   $TEX_ADMIN_ADDRESS
                   $MAIL_FAILURES_ADDRESS
                   $SENDMAIL
+                  $PS_CACHE
+                  $PS_GEN_TMP
 		  $DEFAULTPSRESOLUTION
                   $DIRECTIVE_FILE
                   $THIS_SITE
@@ -58,7 +60,6 @@ $SENDMAIL = q{/usr/sbin/sendmail -t};
 #$CRYPT    = $arXiv::Config::Site::AutoTeX::CRYPT;
 $CRYPT = q{};
 
-# set the default resolution/mode for dvips using bitmap fonts
 #$DEFAULTPSRESOLUTION = defined $arXiv::Config::Site::AutoTeX::DEFAULTPSRESOLUTION ?
 #  $arXiv::Config::Site::AutoTeX::DEFAULTPSRESOLUTION :
 #  600;
@@ -117,20 +118,18 @@ __END__
 
 =head1 NAME
 
-TeX::AutoTeX::Config - central configuration file for TeX::AutoTeX
+TeX::AutoTeX::Config
 
 =head1 DESCRIPTION
 
-This is the main configuration file for TeX::AutoTeX. It contains all
-configuration parameters for TeX::AutoTeX and allows TeX::AutoTeX to be used
-separately from other arXiv software.
+Centralization of configuration parameters for TeX::AutoTeX so that
+TeX::AutoTeX can be used separately from other arXiv software.
 
-The settings in this file must be customized to reflect PATH settings and
-executable names of the local TeX installation, maintainer email addresses,
-etc.. The comments for each setting should be used as guidance.
+The settings in this file must be customized to reflect paths and executable
+names of the local TeX installation, maintainer email addresses, etc..
 
-In the sample configuration presented in this file those variables, which are
-not identical across all arXiv sites, are imported from the
+In the sample configuration presented in this file as distributed variables
+which are not identical across all arXiv sites are imported from the
 C<arXiv::Config::Site> namespace. These settings vary depending on the
 capabilities of each mirror and their individual setup.
 
@@ -150,7 +149,7 @@ capabilities of each mirror and their individual setup.
  and that the input of others will benefit arXiv.org.
 
  Code developed and contributed to by Tanmoy Bhattacharya, Rob
- Hartill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
+ Harthill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
  Refactored to separate generic code from arXiv.org specific code
  by Stephen Marsh, Michael Fromerth, and Simeon Warner 2005/2006.
 
