@@ -1,18 +1,18 @@
 package TeX::AutoTeX::Exception;
 
 #
-# $Id: Exception.pm,v 1.7.2.7 2011/01/27 18:42:27 thorstens Exp $
-# $Revision: 1.7.2.7 $
+# $Id: Exception.pm,v 1.7.2.5 2011/01/22 04:52:14 thorstens Exp $
+# $Revision: 1.7.2.5 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/Exception.pm,v $
 #
-# $Date: 2011/01/27 18:42:27 $
+# $Date: 2011/01/22 04:52:14 $
 # $Author: thorstens $
 #
 
 use strict;
 ### use warnings;
 
-our ($VERSION) = '$Revision: 1.7.2.7 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.7.2.5 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 use parent qw(Error);
 use overload (q{""} => 'stringify');
@@ -58,7 +58,7 @@ use parent qw(TeX::AutoTeX::Exception);
 
 =head1 NAME
 
-TeX::AutoTeX::Exception - framework for exception handling in TeX::AutoTeX
+TeX::AutoTeX::Exception
 
 =head1 DESCRIPTION
 
@@ -71,14 +71,10 @@ easily added if necessary.
 
 =head2 new
 
-Instantiate an Exception object with customization of the textual
-representation of the error message.
+instantiate an Exception object with some customization of
 
 =head1 BUGS AND LIMITATIONS
 
-Using the C<Error> module is no longer recommended. Exception handling should be
-migrated to something like C<Try::Tiny> or C<Error::TryCatch>.
-
 Please report bugs to L<www-admin|http://arxiv.org/help/contact>
 
 =head1 AUTHOR
