@@ -1,18 +1,18 @@
 package TeX::AutoTeX::HyperTeX;
 
 #
-# $Id: HyperTeX.pm,v 1.10.2.7 2011/01/27 18:42:28 thorstens Exp $
-# $Revision: 1.10.2.7 $
+# $Id: HyperTeX.pm,v 1.10.2.6 2011/01/20 18:56:27 thorstens Exp $
+# $Revision: 1.10.2.6 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/HyperTeX.pm,v $
 #
-# $Date: 2011/01/27 18:42:28 $
+# $Date: 2011/01/20 18:56:27 $
 # $Author: thorstens $
 #
 
 use strict;
 ### use warnings;
 
-our ($VERSION) = '$Revision: 1.10.2.7 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.10.2.6 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 sub copy_source_from_hyper {
   my ($this_type, $file, $dir, $log, $local_hyper_transform) = @_;
@@ -218,7 +218,7 @@ __END__
 
 =head1 NAME
 
-TeX::AutoTeX::HyperTeX - filter for augmenting TeX source with hypertex facilities
+TeX::AutoTeX::HyperTeX
 
 =head1 DESCRIPTION
 
@@ -242,7 +242,7 @@ original AutoTeX code. See HISTORY below.
  and that the input of others will benefit arXiv.org.
 
  Code developed and contributed to by Tanmoy Bhattacharya, Rob
- Hartill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
+ Harthill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
  Refactored to separate generic code from arXiv.org specific code
  by Stephen Marsh, Michael Fromerth, and Simeon Warner 2005/2006.
 
